pub enum ExternalAddress {
Account(ExternalAccountAddress),
Contract(ExternalContractAddress),
}Expand description
Either an external contract address or an external account address.
External means that it is an entity that exists on an external node.
Variants
Account(ExternalAccountAddress)
Contract(ExternalContractAddress)