pub struct ContractInvokeError {
pub energy_used: Energy,
pub module_load_energy: Energy,
pub transaction_fee: Amount,
pub trace_elements: Vec<DebugTraceElement>,
pub kind: ContractInvokeErrorKind,
}Expand description
An error that occurred during a Chain::contract_update or
Chain::contract_invoke.
Fields
energy_used: EnergyThe energy used.
module_load_energy: EnergyThe amount of Energy that was charged based on the sizes of the Wasm
modules invoked.
transaction_fee: AmountThe transaction fee. For Chain::contract_update, this is the amount
charged to the invoker account.
trace_elements: Vec<DebugTraceElement>Trace elements that occurred before the contract failed.
kind: ContractInvokeErrorKindThe specific reason for why the invocation failed.
Implementations
Sourceimpl ContractInvokeError
impl ContractInvokeError
Sourcepub fn return_value(&self) -> Option<&[u8]>
pub fn return_value(&self) -> Option<&[u8]>
Try to extract the value returned.
This only returns Some if the contract rejected on its own.
As opposed to when it runs out of energy, traps, or similar, in which
case there won’t be a return value.
Sourcepub fn reject_code(&self) -> Option<i32>
pub fn reject_code(&self) -> Option<i32>
If the contract execution rejected the transaction, this returns the code the contract used to signal the rejection.
Sourcepub fn parse_return_value<T: Deserial>(&self) -> ParseResult<T>
pub fn parse_return_value<T: Deserial>(&self) -> ParseResult<T>
Try to extract and parse the value returned into a type that implements
Deserial.
Returns an error if the return value:
- isn’t present
- see
Self::return_valuefor details about when this happens
- see
- is present
- but could not be parsed into
T - could parse into
T, but there were leftover bytes
- but could not be parsed into