#[repr(transparent)]pub struct Timestamp {
pub millis: u64,
}Expand description
Timestamp represented as milliseconds since unix epoch.
Timestamps from before January 1st 1970 at 00:00 are not supported.
Fields
millis: u64Milliseconds since unix epoch.
Implementations
Sourceimpl Timestamp
impl Timestamp
Sourcepub const fn from_timestamp_millis(millis: u64) -> Timestamp
pub const fn from_timestamp_millis(millis: u64) -> Timestamp
Construct timestamp from milliseconds since unix epoch.
Sourcepub const fn timestamp_millis(&self) -> u64
pub const fn timestamp_millis(&self) -> u64
Milliseconds since the UNIX epoch.
Sourcepub fn checked_add(self, duration: Duration) -> Option<Timestamp>
pub fn checked_add(self, duration: Duration) -> Option<Timestamp>
Add duration to the timestamp. Returns None if the resulting timestamp
is not representable, i.e., too far in the future.
Sourcepub fn checked_sub(self, duration: Duration) -> Option<Timestamp>
pub fn checked_sub(self, duration: Duration) -> Option<Timestamp>
Subtract duration from the timestamp. Returns None instead of
overflowing if the resulting timestamp would be before the Unix
epoch.
Sourcepub fn duration_between(self, other: Timestamp) -> Duration
pub fn duration_between(self, other: Timestamp) -> Duration
Compute the duration between the self and another timestamp. The duration is always positive, and is the difference between the the more recent timestamp and the one further in the past.
Sourcepub fn duration_since(self, before: Timestamp) -> Option<Duration>
pub fn duration_since(self, before: Timestamp) -> Option<Duration>
Compute duration since a given timestamp. Returns None if given time
is in the future compared to self.